package loadmetadataasync;

import com.adbs.ast.MetadataBase;
import com.adbs.metadata.JdbcMetadataProvider;
import com.adbs.querybuilder.QueryBuilder;
import com.adbs.syntax.SQLiteSyntaxProvider;
import java.io.File;
import java.sql.DriverManager;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.SwingWorker;

public class TestFrame extends javax.swing.JFrame
{
    public TestFrame()
	{
        initComponents();

		queryBuilder1.setSyntaxProvider(new SQLiteSyntaxProvider());

		// Disable the control so it will be unusable untill the metadata is loaded
		queryBuilder1.setEnabled(false);

		// Run metadata loading in separate thread
		(new SwingWorker<MetadataBase, Object>()
		{
			@Override
			protected MetadataBase doInBackground()
			{
				QueryBuilder tmpQueryBuilder = new QueryBuilder(true);

				try
				{
					// Create connection string for local demo database
					File currentDirObject = new File(".");
					String connectionString = "jdbc:sqlite:/" + currentDirObject.getCanonicalPath() + "\\demo.sqlite";

					// Connect the demo database
					Class.forName("org.sqlite.JDBC");
					JdbcMetadataProvider metadataProvider = new JdbcMetadataProvider();
					metadataProvider.setConnection(DriverManager.getConnection(connectionString));

					// Set up the temporary QueryBuilder
					tmpQueryBuilder.setMetadataProvider(metadataProvider);
					tmpQueryBuilder.setSyntaxProvider(new SQLiteSyntaxProvider());

					// Load metadata
					tmpQueryBuilder.refreshMetadata();

					// Force fields loading for all metadata objects
					tmpQueryBuilder.getMetadataContainer().loadFields();

					// Put copy of filled metadata container to thread result
					return tmpQueryBuilder.getMetadataContainer().clone(null, tmpQueryBuilder.getSQLContext());
				}
				catch (Exception ex)
				{
					Logger.getLogger(TestFrame.class.getName()).log(Level.SEVERE, null, ex);
				}

				return null;
			}
			
			@Override
			protected void done()
			{
				try
				{
					// Assign filled metadata container to the main instance of the QueryBuilder
					queryBuilder1.getMetadataContainer().assign(get());

					// Enable the control
					queryBuilder1.setEnabled(true);
				}
				catch (Exception ex)
				{
					Logger.getLogger(TestFrame.class.getName()).log(Level.SEVERE, null, ex);
				}
			}
		}).execute();
	}

    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        queryBuilder1 = new com.adbs.querybuilder.QueryBuilder();
        jScrollPane2 = new javax.swing.JScrollPane();
        jTextArea1 = new javax.swing.JTextArea();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        getContentPane().add(queryBuilder1, java.awt.BorderLayout.CENTER);

        jScrollPane2.setBorder(null);

        jTextArea1.setBackground(java.awt.SystemColor.info);
        jTextArea1.setColumns(20);
        jTextArea1.setEditable(false);
        jTextArea1.setFont(new java.awt.Font("Tahoma", 1, 11)); // NOI18N
        jTextArea1.setForeground(new java.awt.Color(128, 0, 0));
        jTextArea1.setRows(2);
        jTextArea1.setText("This applicaton demonstrates asynchronous metadata loading.\nPlease see the source code.");
        jTextArea1.setAutoscrolls(false);
        jTextArea1.setFocusable(false);
        jTextArea1.setMargin(new java.awt.Insets(2, 5, 2, 2));
        jScrollPane2.setViewportView(jTextArea1);

        getContentPane().add(jScrollPane2, java.awt.BorderLayout.PAGE_START);

        pack();
    }// </editor-fold>//GEN-END:initComponents

	
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JScrollPane jScrollPane2;
    private javax.swing.JTextArea jTextArea1;
    private com.adbs.querybuilder.QueryBuilder queryBuilder1;
    // End of variables declaration//GEN-END:variables
  
}
